summaryrefslogtreecommitdiff
path: root/usr/src/uts/common/vm/seg_dev.h
diff options
context:
space:
mode:
Diffstat (limited to 'usr/src/uts/common/vm/seg_dev.h')
-rw-r--r--usr/src/uts/common/vm/seg_dev.h13
1 files changed, 6 insertions, 7 deletions
diff --git a/usr/src/uts/common/vm/seg_dev.h b/usr/src/uts/common/vm/seg_dev.h
index c498c06ecf..451d61963d 100644
--- a/usr/src/uts/common/vm/seg_dev.h
+++ b/usr/src/uts/common/vm/seg_dev.h
@@ -2,9 +2,8 @@
* CDDL HEADER START
*
* The contents of this file are subject to the terms of the
- * Common Development and Distribution License, Version 1.0 only
- * (the "License"). You may not use this file except in compliance
- * with the License.
+ * Common Development and Distribution License (the "License").
+ * You may not use this file except in compliance with the License.
*
* You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
* or http://www.opensolaris.org/os/licensing.
@@ -20,7 +19,7 @@
* CDDL HEADER END
*/
/*
- * Copyright 2005 Sun Microsystems, Inc. All rights reserved.
+ * Copyright 2006 Sun Microsystems, Inc. All rights reserved.
* Use is subject to license terms.
*/
@@ -42,12 +41,12 @@
#pragma ident "%Z%%M% %I% %E% SMI"
-#include <sys/project.h>
-
#ifdef __cplusplus
extern "C" {
#endif
+struct proc;
+
/*
* Structure whose pointer is passed to the segdev_create routine
*/
@@ -110,7 +109,7 @@ struct devmap_pmem_cookie {
pgcnt_t dp_npages; /* number of allocated mem pages */
page_t **dp_pparray; /* pages allocated for this cookie */
vnode_t *dp_vnp; /* vnode associated with this cookie */
- kproject_t *dp_projp; /* project ptr for resource ctl */
+ proc_t *dp_proc; /* proc ptr for resource control */
};
#ifdef _KERNEL